package
module
Version:
v0.0.0-...-28fa420
Opens a new window with list of versions in this module.
Published: Jun 16, 2022
License: 0BSD
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
partycode
Package partycode generates party codes.
Documentation
¶
type Generator struct {
}
type Rand interface {
Intn(n int) int
}
Rand is a source of random numbers.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.